/*
 * Copyright (C) 2022, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */

import QtQuick 2.0
import QtQuick.Layouts 1.12
import org.ukui.sidebar.core 1.0
import org.ukui.sidebar.shortcut.core 1.0
import org.ukui.quick.items 1.0 as UkuiItems
import org.ukui.quick.platform 1.0 as Platform

Item {
    height: panelLayout.height + 38
    ColumnLayout {
        id: panelLayout
        width: parent.width
        spacing: 16

        anchors.top: parent.top
        anchors.topMargin: 14
        anchors.bottomMargin: 24

        Item {
            Layout.preferredWidth: parent.width - 40
            Layout.preferredHeight: 32
            Layout.alignment: Qt.AlignHCenter

            RowLayout {
                anchors.fill: parent
                spacing: 0

                RowLayout {
                    Layout.fillWidth: true
                    Layout.fillHeight: true

                    UkuiItems.DtThemeText {
                        Layout.fillWidth: true
                        Layout.preferredHeight: 20
                        Layout.alignment: Qt.AlignVCenter

                        text: dropArea.isEdit ? qsTr("Added components") : qsTr("Shortcuts")
                        textColor: Platform.GlobalTheme.kFontPrimary
                        elide: Text.ElideRight
                        verticalAlignment: Text.AlignVCenter
                        horizontalAlignment: Text.AlignLeft
                    }
                }

                UkuiItems.DtThemeButton {
                    Layout.preferredWidth: 32
                    Layout.preferredHeight: 32
                    Layout.alignment: Qt.AlignVCenter

                    background.radius: mainWindow.isTabletMode ? Platform.GlobalTheme.kRadiusMax : Platform.GlobalTheme.kRadiusNormal
                    background.backgroundColor: containsPress ? Platform.GlobalTheme.kContainAlphaClick
                                                              : containsMouse ? Platform.GlobalTheme.kContainAlphaHover
                                                                              : Platform.GlobalTheme.kContainSecondaryAlphaNormal

                    icon.source: editModel.editIconName()
                    icon.mode: UkuiItems.Icon.AutoHighlight

                    onClicked: {
                        dropArea.isEdit = !dropArea.isEdit;
                    }
                }
            }
        }

        EditButtonView {
            property bool isEdit: false
            id: dropArea
            Layout.preferredWidth: childrenRect.width
            Layout.preferredHeight: childrenRect.height
            Layout.alignment: Qt.AlignHCenter

            Connections {
                target: mainWindow
                function onVisibleChanged() {
                    if (!mainWindow.visible) dropArea.isEdit = false;
                }
            }
        }

        Item {
            Layout.preferredWidth: childrenRect.width
            Layout.preferredHeight: childrenRect.height
            Layout.alignment: Qt.AlignHCenter

            BaseButtonView {
                anchors.centerIn: parent
                Layout.alignment: Qt.AlignHCenter
                columns: 1
                itemWidth: 356
                itemHeight: 56
                rowSpacing: 16
                buttoonType: ShortcutPlugin.ProgressBar
                buttonComponent: ProgressBar {}
            }
        }
    }
}
